JokerStage<T> class

A widget that listens to a JokerAct and rebuilds whenever the state changes.

JokerStage is the most direct way to bind a state object's value to the UI. It rebuilds on every notification, providing the entire state object to the builder.

For more optimized rebuilds based on a slice of the state, consider using JokerFrame.

{@tool snippet}

Direct Instantiation

final counterAct = Joker<int>(0); // Can be a Joker or a Presenter

class CounterText extends StatelessWidget {
  const CounterText({super.key});

  @override
  Widget build(BuildContext context) {
    return JokerStage<int>(
      joker: counterAct,
      builder: (context, count) {
        return Text('Count: $count');
      },
    );
  }
}

{@end-tool}

{@tool snippet}

Using the .perform() Extension

For a more fluent syntax, you can use the perform extension method on any JokerAct instance (like a Joker or Presenter) directly inside your build method.

final counterAct = Joker<int>(0);

// Inside a build method:
counterAct.perform(
  builder: (context, count) => Text('Count: $count'),
);

{@end-tool}

Inheritance

Constructors

JokerStage({Key? key, required JokerAct<T> act, required JokerStageBuilder<T> builder})
Creates a JokerStage that rebuilds when the act notifies listeners.
const

Properties

act JokerAct<T>
The JokerAct instance to listen to.
final
builder JokerStageBuilder<T>
The builder function that rebuilds when the state changes.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited